<div class="pagination">
    {% if has_previous %}
        <li><a href="{% if get_params %}?{{ get_params }}&{% else %}?{% endif %}page={{ previous }}">&laquo; Prev</a></li>
    {% endif %}
    {% if not in_leading_range %}
        {% for p in pages_outside_trailing_range %}
            <li><a href="{% if get_params %}?{{ get_params }}&{% else %}?{% endif %}page={{ p }}">{{ p }}</a></li>
        {% endfor %}
        <li><span class="ellipsis">...</span></li>
    {% endif %}
    {% for p in page_range %}
        {% if p == page %}
            <li><span class="active">{{ p }}</span></li>
        {% else %}
            <li><a href="{% if get_params %}?{{ get_params }}&{% else %}?{% endif %}page={{ p }}">{{ p }}</a></li>
        {% endif %}
    {% endfor %}
    {% if not in_trailing_range %}
        <li><span class="ellipsis">...</span></li>
        {% for p in pages_outside_leading_range %}
            <li><a href="{% if get_params %}?{{ get_params }}&{% else %}?{% endif %}page={{ p }}">{{ p }}</a></li>
        {% endfor %}
    {% endif %}
    {% if has_next %}
        <li><a href="{% if get_params %}?{{ get_params }}&{% else %}?{% endif %}page={{ next }}">Next &raquo;</a></li>
    {% endif %}
</div>
